@@ -2,4 +2,4 @@ from core import (
 	ifthis, IfThis,
 	thenthat, ThenThat 
 )
-from lib import channels
+from channels import channels
