@@ -139,9 +139,12 @@ class IfThis:
                 if k not in body:
                     raise ValueError('Body missing required key {}'.format(k))
 
-        elif util.is_regex(self.pattern):
+        elif is_instance(obj, re._pattern_type):
 
             m = self.pattern.search(raw)
+            if not m:
+                raise ValueError('Bad Regex')
+
             body = m.groupdict()
 
         else:
@@ -289,5 +292,11 @@ def thenthat(channel, **dkwargs):
 
   return wrapper
 
+def now():
+  dt = datetime.utcnow()
+  dt = t.replace(tzinfo=pytz.utc)
+  return int(dt.strftime('%s'))
+
+
 
 
