@@ -1,6 +1,7 @@
 import re
 from string import punctuation
 from datetime import datetime
+import pytz
 import json
 import sys
 
@@ -11,6 +12,7 @@ punct = frozenset(punctuation)
 
 def now(dt=False):
 	d = datetime.utcnow()
+	d = d.replace(tzinfo=pytz.utc)
 	if dt:
 		return d
 	else:
